@@ -1,4 +1,4 @@
-/* $Id: union.h,v 1.20 2004/11/13 00:53:20 bdejean Exp $ */
+/* $Id: union.h,v 1.21 2005/01/10 08:43:04 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,6 +43,7 @@
 #include <glibtop/procsegment.h>
 #include <glibtop/procargs.h>
 #include <glibtop/procmap.h>
+#include <glibtop/procopenfiles.h>
 
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
@@ -80,6 +81,7 @@ union _glibtop_union
 	glibtop_netlist		netlist;
 	glibtop_netload		netload;
 	glibtop_ppp		ppp;
+	glibtop_proc_open_files proc_open_files;
 };
 
 G_END_DECLS
