@@ -1,4 +1,4 @@
-/* $Id: slave.c,v 1.31 2004/07/18 20:33:56 bdejean Exp $ */
+/* $Id: slave.c,v 1.33 2005/02/15 12:48:33 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,6 +22,7 @@
 */
 
 #include "daemon.h"
+#include <glibtop/error.h>
 
 void
 handle_slave_connection (int input, int output)
@@ -42,13 +43,13 @@ handle_slave_connection (int input, int output)
 	while (do_read (input, cmnd, sizeof (glibtop_command))) {
 #ifdef SLAVE_DEBUG
 		fprintf (stderr, "Slave %d received command "
-			 "%d from client.\n", getpid (), cmnd->command);
+			 "%llu from client.\n", getpid (), cmnd->command);
 #endif
 
 		if (cmnd->data_size >= BUFSIZ)
-			glibtop_error ("Client sent %d bytes, "
-				       "but buffer is %d",
-				       cmnd->size, BUFSIZ);
+			glibtop_error ("Client sent %llu bytes, "
+				       "but buffer is %lu",
+				       cmnd->size, (unsigned long)BUFSIZ);
 
 		memset (resp, 0, sizeof (glibtop_response));
 
@@ -56,7 +57,7 @@ handle_slave_connection (int input, int output)
 
 		if (cmnd->data_size) {
 #ifdef SLAVE_DEBUG
-			fprintf (stderr, "Client has %d bytes of data.\n",
+			fprintf (stderr, "Client has %llu bytes of data.\n",
 				 cmnd->data_size);
 #endif
 
@@ -249,7 +250,7 @@ handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
 		break;
 #endif
 	default:
-		glibtop_error ("Child received unknown command %u",
+		glibtop_error ("Child received unknown command %llu",
 			       cmnd->command);
 		break;
 	}
