@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
+/* $Id: procsegment.c,v 1.5 2004/10/22 15:35:57 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -31,7 +31,7 @@
 
 #include "utils.h"
 
-static const unsigned long _glibtop_sysdeps_proc_segment = 
+static const unsigned long _glibtop_sysdeps_proc_segment =
 (1 << GLIBTOP_PROC_SEGMENT_TEXT_RSS) + (1 << GLIBTOP_PROC_SEGMENT_SHLIB_RSS) +
 (1 << GLIBTOP_PROC_SEGMENT_DATA_RSS) + (1 << GLIBTOP_PROC_SEGMENT_STACK_RSS);
 
@@ -53,15 +53,12 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 	struct procsinfo *pinfo;
 	int pagesize;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
+
 	memset (buf, 0, sizeof (glibtop_proc_segment));
 
 	pinfo = _glibtop_get_procinfo(server, pid);
-	if (pinfo == NULL)
-	{
-		glibtop_error_io_r (server, "Cannot read procsinfo");
-
-		return;
-	}
+	if (pinfo == NULL) return;
 
 	pagesize = sysconf(_SC_PAGESIZE);
 
