@@ -15,10 +15,9 @@
 #include <stdlib.h>
 
 void
-G_GNUC_INTERNAL
 _glibtop_linux_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
-				      const char *path);
+				      const char *path) G_GNUC_INTERNAL;
 
 /*
  * Linux 2.6.x
@@ -39,7 +38,8 @@ get_partition(const char *mountpoint)
 	if(stat(mountpoint, &statb) == -1)
 		return NULL;
 
-	g_return_val_if_fail((partitions = fopen("/proc/partitions", "r")), NULL);
+	if((partitions = fopen("/proc/partitions", "r")) == NULL)
+		return NULL;
 
 	while(fgets(line, sizeof line, partitions))
 	{
